package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut

__DATA__

M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````@`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)`````````!010``3`$&
M`$-VQ$4``````````.``#P,+`0(X`#X```#"````!```<!(````0````4```
M``!````0`````@``!`````$````$```````````0`0``!```?IP!``,`````
M`"```!``````$```$````````!````````````````#0``!H"@```.```'`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"YT97AT````!#T````0````/@````0`````````
M`````````&```&`N9&%T80```'``````4`````(```!"````````````````
M``!```#`+G)D871A``"`4P```&````!4````1```````````````````0```
M0"YB<W,`````,`(```#``````````````````````````````(```,`N:61A
M=&$``&@*````T`````P```"8``````````````````!```#`+G)S<F,```!P
M(````.`````B````I```````````````````0```P```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%6)Y8/L&(E=^(M5
M"#';B77\BP(Q]HL`/9$``,!W0SV-``#`<EN^`0```,<$)`@````QTHE4)`3H
MQ#4``(/X`71ZA<!T#L<$)`@```#_T+O_____B=B+=?R+7?B)[%W"!``]E```
MP'3"=TH]DP``P'2TB=B+=?R+7?B)[%W"!`"0/04``,!T6ST=``#`=<7'!"0$
M````,?:)="0$Z&`U``"#^`%T:H7`=*K'!"0$````_]#KFCV6``#`Z]''!"0(
M````N0$```")3"0$Z#`U``"%]@^$=O___^@S-P``Z6S____'!"0+````,<F)
M3"0$Z`PU``"#^`%T,(7`#X12____QP0D"P```/_0Z3_____'!"0$````N`$`
M``")1"0$Z-PT``#I)?___\<$)`L```"[`0```(E<)`3HPC0``.D+____C;8`
M````C;PG`````%6)Y5.#["2-7?C'!"0`$$``Z"HV``"#[`3HHC8``,=%^```
M``"X`,!``(U5](E<)!"+#2!00`")1"0$B50D"(E,)`S'!"0$P$``Z)$T``"A
M<,%``(7`=%BC,%!``(L5#--``(72#X6+````@_K@=""A<,%``(E$)`2+'0S3
M0`"+2S")#"3H1C0``(L5#--``(/ZP'0;BQUPP4``B5PD!(L-#--``(M14(D4
M).@@-```Z`LT``"+'3!00`")&.C.-0``@^3PZ-8S``"+"(E,)`B+%0#`0`")
M5"0$H03`0`")!"3H.2\``(G#Z*(S``")'"3H.C4``(E$)`2+%0S30`"+0A")
M!"3HQ3,``(L5#--``.E5____C78`C;PG`````%6)Y8/L",<$)`$```#_%>S2
M0`#HR/[__Y"-M"8`````58GE@^P(QP0D`@```/\5[-)``.BH_O__D(VT)@``
M``!5BPTPTT``B>5=_^&-="8`58L-&--``(GE7?_AD)"0D%6)Y5WI]S8``)"0
MD)"0D)!5B>6#[!CHQ3(``(D$)+H$8$``N:!%0`")5"0,N@Y@0`")3"0(B50D
M!.BR,@``R<-5B>575E.#[!R%P(E%\(E5['1]Z,@R``"+"(7)='*+3?`/M@&$
MP`^5PCP]#Y7`#[;`A<)T%4$/M@&$P`^5PCP]#Y7`#[;`A<)UZXG/BTWP*<_H
MBC(``(L8BS.%]G0RB?:)?"0(BU7PB30DB50D!.CM,P``A<!U!H`\-SUT'8/#
M!(LSA?9UVHUV`(V\)P`````QP(/$'%M>7UW#Z$$R``"+$(M%["G3P?L"B1B-
M1#X!Z^'K#9"0D)"0D)"0D)"0D)!5B>6-5?R#[`CH,O___\G#58GE5U:)UE.#
M["R)1>PQP(`Z/0^4P`'&B30DZ$`S``")1>B+1>R-5?#H`O___X7`B<</A/<`
M``")!"3H(#,``#M%Z`^#S@```(M][.L#B?9'#[8'A,`/E<(\/0^5P`^VP(7"
M=>OHIC$``(M5\(E5V(L`B474Z%8Q``")!"3H+C$``(G#Z$<Q``")!"3H'S$`
M`(L0BT7LBTWH*<>-1`\"B40D!(L#B00D_Q*+5=B+3=2%P(D$D;K_____=%'H
M3S$``(L0BT7PBSR"BU7L#[8"0HE5[(3`="$\/>L;D(UT)@"(!XM-[$</MA%!
MB4WLA-*(T'0%@/H]=>C&!SU'C70F``^V!D:(!T>$P'7U,=*#Q"R)T%M>7UW#
M#[8&1H@'1X3`=.D/M@9&B`='A,!UZNO<Z-PP``"+&,=%Y`````#K!Y#_1>2#
MPP2+`X7`=?2+/1#`0`"%_P^%@@```+D!````B0T0P$``Z&8P``")!"3H/C``
M`(G#Z%<P``")!"3H+S```(M]Y(L0P><"C4<(B40D!(L#B00D_Q*Z_____X7`
MB<,/A&?____H93```(E\)`B+`(D<)(E$)`3HDS$``.A.,```B1CH1S```(L`
M,=*+3>2)5(@$B4WPZ6W^___H+S```(E%X.@G,```B47<Z-\O``")!"3HMR\`
M`(G#Z-`O``")!"3HJ"\``(M-Y(L0C02-"````(E$)`B+3=R+`8E$)`2+`XD$
M)/]2!(M5X(D"Z-TO``"+&+K_____A=MUANG*_O__C;8`````C;PG`````%6)
MY5.#[`2)PXVT)@````"-5?B)V.C&_/__A<!T&^B=+P``BQ"+1?B-%(*+0@2%
MP(D"=-R#P@3K\EA;7<.-=@!5,<")Y5W#B?:-O"<`````5;@J8$``B>575E.!
M[$P!``"+?0CH-_W__XF%U/[__[@$`0``B40D"(V%V/[__XE$)`3'!"0`````
MZ`(Q``"#[`R%P'4KH0!00`")/"2)1"0$Z$HP``"%P'0\B?JX,V!``.CZ_/__
MC67TB?A;7E]=PXV5V/[__[@S8$``C;78_O__Z-K\__^)-"3H4C```(UE]%M>
M7UW#B3PDZ"(P``")A=#^__^A!%!``(E$)`2+10R)!"2-M@````"-O"<`````
MZ,LO``"%P(G#=(^`.`!U!;M`8$``BX74_O__A<!T&HE<)`2+M=3^__^)-"3H
MCR\``(7`#X37````B1PDZ+\O``"+#0!00`")P@^V`3A$$_]U(HVT)@````"-
MO"<`````2L8$$P"+#0!00``/M@$X1!/_=.R+M=#^__^-1#(!/0,!```/CQ'_
M__^)3"0,N$)@0`")1"0$C878_O__B5PD"(E\)!")!"3H!"\``.B_+0``B00D
MZ'<M``")QNBP+0``B00DZ'@M``")P^BA+0``B00DZ&DM``"+$(ET)`B-M=C^
M__^)="0$BP.)!"3_4E"%P'4=Z'@M``")!"3H,"T```^W0`8E`/```#T`@```
M=!6A!%!``,<$)`````")1"0$Z=O^___H1BT``(D$).@.+0``B</H-RT``(D$
M).C_+```BQ"X`0```(E$)`B)="0$BP.)!"3_$H7`=;6-E=C^__^X,V!``.@U
M^___C878_O__B00DZ*<N``#I4/[__XGV58GE5HMU"%.)\P^V!H3`="^(PJ$`
M4$``#[8`ZPR-=@`/MA&)RX32=!<XPHU+`77P#[81B<Z)RX32=>Z0C70F`%N)
M\%Y=PXUV`(V\)P````!5B>53@^P4BUT(A=MT"@^V`X3`B$7[=1C'10A`8$``
M@\046UWI)RX``(VT)@````")'"3H^"T``(T,&(U1_SG:=CZA`%!```^V`#A!
M_W4*D$HYVG8K.`)T]SG:=B.+#0!00`#K!4HYVG86#[8!.`)U].L-D)"0D)"0
MD)"0D)"0D#G:=$J+#0!00`"-M@````!*.=IV!P^V`3@"=/0IVC')C4("/00!
M``!W'(E<)`2-0@&)1"0(QP0D(,!``.@/+0``N2#`0`"#Q!2)R%M=PP^V5?NA
M`%!``#H0#X0Y____B44(Z3C___^)]HV\)P````!5B>575H/L,*%,8$``B47(
MH5!@0`")1<RA5&!``(E%T*%88$``B474H5Q@0`")1=BA8&!``(E%W*%D8$``
MB47@H6A@0`")1>0/MP5L8$``9HE%Z+AN8$``Z-/[__^X?F!``.C)^___N"I@
M0`#HO_O__[B*8$``Z+7[__^XE&!``.BK^___N)Y@0`#HH?O__[@S8$``Z)?[
M__^XJ&!``.B-^___N+%@0`#H@_O__[B\8$``Z!GY__^%P'0,B<*XE&!``.@9
M^?__N,U@0`#H__C__X7`=`R)PKC?8$``Z/_X__^XZF!``.CE^/__A<!T(HG"
MN"I@0`#HY?C__[KZ8$``N&Y@0`#HUOC__X/$,%Y?7<.X_&!``.BU^/__A<")
MPG0'N(I@0`#KSOR_#6%``(U%V;D*````B<;SIG6_C57CN(I@0`#KL(UV`(V\
M)P````!5B>6#[`BA"%!``(/X_W0"R<.XBF!``.AD^/__,=*%P'0>#[8`A,!T
M%SPP=!.Z`0```(VT)@````"-O"<`````B14(4$``B=#)PXVV`````%4QR8GE
M5U93B<.![%P!``")A:3^__^#PQR-M"8`````BS.#PP2)\HGPP>((@>(``/\`
MP>X(P>`8"=")\H'B`/\``,'N$`G0"?")A(VH_O__08/Y#W[*N1````"0C70F
M`(N$C8C^__^+G(V<_O__BY2-</[__XN\C6C^__\QV#'0,?C1P(F$C:C^__]!
M@_E/?L^+A:3^__^+4`2+.(F5H/[__XM("(GZP<(%B8V<_O__BT`,BXV@_O__
MB[6<_O__B868_O__BX6@_O__BYV8_O__(?'WT(NUJ/[__R'8"<&+G9S^__\!
MRHN-I/[__XM!$,&%H/[__QX!PHN-H/[__P'RB?B-LIEY@EKWT"'Y(=B)\@G!
MBX6L_O__P<(%`<J+C9C^___!QQX!R@'"B?"-FIEY@EKWT".%H/[__XGQ(?F)
MVL'&'L'"!0G!BX6<_O__`<J+C;#^__\!PHG8`<KWT(G9(?@A\0G!@<*9>8):
MBX6@_O__B968_O__P<(%`<H!PHN%M/[__XN-F/[__P'"BX68_O__@<*9>8):
MB96<_O__P<,>(=G!A9C^__\>]]`A\`G!P<(%BX6X_O__`<H!^HN-G/[__P'"
MBX68_O__@<*9>8):B96@_O__P<(%(<&+A9S^___WT"'8"<&+A;S^__\!RL&%
MG/[__QX!\HN-H/[__P'"BX6<_O__B[68_O__C;J9>8):(<&+A:#^___!A:#^
M__\>B?K!P@7WT"'P"<&+M<#^__\!RHGXBXV@_O__`=KWT(N=G/[__P'RC;*9
M>8):(=B)\B'Y"<'!P@4!RHN-F/[__XN%Q/[__P'*`<*)\/?0P<<>(X6@_O__
MC9J9>8):B?$A^8G:P<(%"<&+A9S^__\!RHN-R/[__\'&'@'"B=@!RO?0B=DA
M^"'Q"<&!PIEY@EJ+A:#^__^)E9C^___!P@4!R@'"BX7,_O__P<,>BXV8_O__
M`<*+A9C^___!A9C^__\>@<*9>8):(=F)E9S^___WT"'P"<'!P@6+A=#^__\!
MR@'ZBXV<_O__`<*+A9C^__^!PIEY@EJ)E:#^___!P@4AP8N%G/[___?0(=@)
MP0'*BX74_O__`?+!A9S^__\>BXV@_O__`<*+A9S^__^-NIEY@EJ+M9C^__^)
M^B'!BX6@_O__P<(%]]`A\`G!B[78_O__`<K!A:#^__\>`=J+C:#^__^+G9S^
M__\!\HGXC;*9>8):]]`A^2'8B?()P<'"!8N%W/[__P'*BXV8_O__P<<>`<H!
MPHGP]]`CA:#^__^-FIEY@EJ)\2'YB=K!P@4)P8N%G/[__P'*BXW@_O__P<8>
M`<*)V`'*]]")V2'X(?$)P8'"F7F"6HN%H/[__XF5F/[__\'"!0'*`<*+A>3^
M__^+C9C^___!PQX!PHN%F/[__\&%F/[__QZ!PIEY@EHAV8F5G/[___?0(?`)
MP<'"!8N%Z/[__P'*`?J+C9S^__\!PHN%F/[__X'"F7F"6HF5H/[__\'"!2'!
MBX6<_O__P86<_O__'O?0(=@)P8N%[/[__P'*`?*+C:#^__^+M9C^__\!PHN%
MG/[__XVZF7F"6HGZP<(%(<&+A:#^___!A:#^__\>]]`A\`G!B[7P_O__`<H!
MVHN-H/[__XGXBYV<_O__`?+WT(VRF7F"6B'YB?(AV,'"!0G!BX68_O__`<K!
MQQZ+G?3^__^+C:#^__\!P@':C9J9>8):B?(Q^HG8,<K!P`6+C?C^__\!T(N5
MG/[__\'&'@'0`<B)V@6AZ]ENB868_O__,?+!P`4Q^HN-_/[__\'#'@'0BY6@
M_O__`="+E9C^__\!R`6AZ]ENB86<_O__,=K!P`7!A9C^__\>,?(!T(N5`/__
M_P'XB[V8_O__`="+E9S^__\%H>O9;HF%H/[__\'`!3'Z,=H!T`'PB[4$____
MBY6@_O__`?#!A9S^__\>B[68_O__C;BAZ]ENP86@_O__'HGXBXV<_O__P<`%
M,<HQ\@'0BY6@_O__`=B+G0C___^+C9S^__\Q^L'''@'8C;"AZ]ENB?`QRHN=
M#/___\'`!8N-H/[__P'0BY68_O__`=`!V(V8H>O9;HGR,?J)V#'*BXT0____
MP<`%`="+E9S^___!QAX!T`'(B=H%H>O9;HN-%/___XF%F/[__S'RP<`%,?K!
MPQX!T(N5H/[__P'0BY68_O__`<@%H>O9;HF%G/[__\'`!3':,?(!T(N5&/__
M_P'X`=`%H>O9;HF%H/[__\'`!<&%F/[__QZ+E9S^__^+O9C^___!A9S^__\>
M,?HQV@'0BXV<_O__`?"+M1S___^+E:#^___!A:#^__\>`?"+M9C^__^-N*'K
MV6XQRHGX,?+!P`6+C9S^__\!T`'8BYT@____BY6@_O__`=B-L*'KV6XQ^HGP
MBYTD____,<K!P`6+C:#^__\!T(N5F/[__\'''@'0`=B)\HV8H>O9;C'ZB=@Q
MRL'`!0'0BY6<_O__BXTH____`=`!R(G:P<8>!:'KV6XQ\HN-+/___XF%F/[_
M_S'ZP<`%`="+E:#^___!PQX!T(N5F/[__P'(P868_O__'@6AZ]ENB86<_O__
M,=K!P`4Q\@'0BY4P____`?B+O9C^__\!T(N5G/[__P6AZ]ENB86@_O__P<`%
M,?K!A9S^__\>,=H!T`'PB[4T____BXV<_O__BY6@_O__`?"+M9C^__^-N*'K
MV6XQRHGX,?+!P`4!T`'8BYTX____P86@_O__'HN5H/[__P'8BXV<_O__C;"A
MZ]ENB?#!P`4Q^C'*`="+E9C^___!QQZ+G3S___^+C:#^__\!T`'8B?*-F*'K
MV6XQ^HG8,<K!P`6+C9S^__\!T(N50/___\'&'@'(BXV@_O__`=")V@6AZ]EN
M,?(Q^HF%F/[__\'`!0'0BY5$____P<,>`<B+C9C^___!A9C^__\>`=")V@GR
M!:'KV6XARHF%G/[__XG9(?$)RL'`!0'0`?B+O4C___^+E9C^__^+C9S^__\!
M^"TD0^1PB86@_O__P<`%"=K!A9S^__\>(<J+C9C^__^+O4S___\AV0G*`="+
ME9S^__\!\(NUF/[__P'XBXV@_O__P86@_O__'@GRB[68_O__(<J+C9S^__^-
MN-R\&X^)^"'QP<`%"<H!T(N-G/[__P'8BY6@_O__BYU0____"<H!V(N-H/[_
M_XN=G/[__XVPW+P;CR'ZB?#!QQ[!P`4AV0G*BYU4____`="+E9C^__^+C:#^
M__\!T(N5H/[__P'8C9C<O!N/(?F)V`GZP<`%(?()RHN-G/[__P'0BY58____
M`<C!QAX!T(GR"?J)\2TD0^1P(?F)A9C^__\AV@G*P<`%BXV@_O__`="+E5S_
M___!PQX!R(N-F/[__P'0B=K!A9C^__\>"?(ARHG9+21#Y'`A\8F%G/[__PG*
MP<`%`="+E9C^__^+C9S^___!A9S^__\>`?@)VHN]8/___R'*BXV8_O__`?@A
MV2TD0^1PB86@_O__"<J+O63____!P`6+C:#^__\!T`'PBY6<_O__B[68_O__
M`?B-N-R\&X^)^,'`!0GR(<K!A:#^__\>B[68_O__BXV<_O__(?$)R@'0BXV<
M_O__`=B+E:#^__^+G6C___\)R@'8BXV@_O__C;#<O!N/(?J+G9S^__^)\,''
M'L'`!2'9"<H!T(N5F/[__XN=;/___XN-H/[__P'0BY6@_O__`=@A^8V8W+P;
MCPGZB=@A\@G*P<`%BXV<_O__`="+E7#____!QAX!R`'0B?()^HGQ(?DM)$/D
M<"':"<J)A9C^__^+C:#^___!P`4!T(N5=/___P'(P<,>`=`M)$/D<(F%G/[_
M_XN-F/[__XG:P868_O__'@GR(<J)V<'`!2'Q"<H!T(N5F/[__XN-G/[__P'X
MB[UX____P86<_O__'@G:(<J+C9C^__\!^"TD0^1PB86@_O__P<`%(=D)RHN-
MH/[__P'0P86@_O__'@'PBY6<_O__B[68_O__B[U\____"?(ARHNUF/[__P'X
MBXV<_O__C;C<O!N/B?C!P`4A\0G*`="+C9S^__\!V(M=@(N5H/[__P'8C;#<
MO!N/BYV<_O__B?#!P`4)RHN-H/[__R'ZP<<>(=D)RHM=A`'0BY68_O__BXV@
M_O__`="+E:#^__\!V"'YC9C<O!N/B=@)^B'RP<`%"<J+C9S^__\!T,'&'HM5
MB`'(`=")\HGQ"?HA^2TD0^1P(=J)A9C^__\)RL'`!8N-H/[__P'0P<,>BU6,
M`<B+C9C^__\!T(G:+21#Y'")A9S^__\)\B'*B=G!P`4A\0G*`="+59`!^`'0
M+21#Y'")A:#^__^+O9S^___!P`7!A9C^__\>P86<_O__'HN5F/[__XN-F/[_
M_PG:(=DA^@G*`="+C9S^__\!\(MUE(N5H/[__\&%H/[__QX!\(NUF/[__XVX
MW+P;CS'*B?@Q\L'`!8N-G/[__P'0`=B+79B+E:#^__\!V(VPUL%BRC'ZB?"+
M79PQRL'`!8N-H/[__P'0BY68_O__P<<>`=`!V(GRC9C6P6+*,?J)V#'*P<`%
M`="+E9S^__^+3:`!T`'(P<8>BTVDB=HM*CZ=-3'RB868_O__,?K!P`4!T(N5
MH/[__\'#'@'0BY68_O__`<C!A9C^__\>+2H^G36)A9S^__\QVL'`!3'R`="+
M5:@!^(N]F/[__P'0BY6<_O__+2H^G36)A:#^___!P`4Q^C':`=`!\(MUK,&%
MG/[__QZ+E:#^__^+C9S^__\!\(NUF/[__XVXUL%BRC'*B?C!P`4Q\HN-G/[_
M_P'0`=B+7;`!V,&%H/[__QZ-L-;!8LJ+7;2)\(N5H/[__\'`!3'Z,<J+C:#^
M__\!T(N5F/[__\'''@'0`=B)\HV8UL%BRC'ZB=@QRL'`!8M-N`'0BY6<_O__
MP<8>`=`!R(G:+2H^G34Q\HM-O(F%F/[__S'ZP<`%`="+E:#^___!PQX!T(N5
MF/[__P'(P868_O__'BTJ/ITUB86<_O__,=K!P`4Q\@'0BU7``?B+O9C^__\!
MT(N5G/[__RTJ/ITUB86@_O__P<`%,?K!A9S^__\>,=H!T`'PBW7$BY6@_O__
MP86@_O__'HN-G/[__P'PB[68_O__C;C6P6+*B?@QRL'`!3'R`="+E:#^__\!
MV(M=R(N-G/[__S'ZP<<>`=B-L-;!8LJ)\#'*BUW,P<`%BXV@_O__`="+E9C^
M__\!T`'8C9C6P6+*B?(Q^HG8,<J+3=#!P`4!T(N5G/[__\'&'@'0`<B)VBTJ
M/ITU,?*)A9C^__\Q^L'`!0'0BY6@_O__BTW4`="+E9C^__\!R,&%F/[__QXM
M*CZ=-<'#'HF%G/[__S':,?+!P`4!T(M5V`'XB[V8_O__`="+E9S^__\M*CZ=
M-8F%H/[__\'`!3'ZP86<_O__'C':`=`!\(MUW(N5H/[__\&%H/[__QZ+C9S^
M__\!\(NUF/[__XVXUL%BRHGX,<K!P`4Q\@'0BXV<_O__`=B+7>`!V(VPUL%B
MRHN%H/[__XGRBYV8_O__P<(%,?@QR(M-Y`'"P<<>`=H!RHN-I/[__P%Q!(L!
M`7D(C90"UL%BRHD1BX6@_O__`4$,BY6<_O__`5$0@<1<`0``6UY?7<.)]HV\
M)P````!5,<")Y5W#B?:-O"<`````58GE5[\884``5E.#[&PQVX`]&&%```#'
M1<@884``QT7,*&%``,=%T#!A0`#'1=0]84``QT780F%``,=%W%1A0`!T2HVV
M`````(V\)P````")^.@YY___A<")QG0%@#@`=0Z+50B)^.@TY___ZQ6)]HDT
M)(M%"(E$)`3H81H``(7`=!)#BWR=R(`_`'7#@\1L6UY?7<.+50B)%"3H8!H`
M`(E%P*$$4$``B00DZ%`:``")-"2+5<`!T(E%O.A`&@``BTV\C40!`HE%N.BA
M&```B00DZ'D8``")1;3HD1@``(D$).AI&```BQ"+1;B+3;2)1"0$BP&)!"3_
M$HET)!"^0F!``(ET)`2)1<2A!%!``(M5Q(E$)`R+10B)%"2)1"0(Z(L9``"+
M5<3I./___XUV`%6X/($``(GE5U93Z,`>``#'1=A584``,<")A>Q^__^X*F!`
M`,=%W%UA0`#'1>!`8$``QT7D5&%``,=%N-]@0`#'1;QB84``QT7`:6%``,=%
MQ'%A0`#'1<AV84``QT7,5&%``,=%J'IA0`#'1:Q_84``QT6P5&%``.CCY?__
MA<")QW0)@#@`#X68`P``OP0!``"^!`$``(F]]'[__^B?%P``B00DZ'<7``")
MP^B0%P``B00DZ&@7``"+$(ET)`2+`XD$)/\2B87H?O__C87T?O__B40D!(N%
MZ'[__XD$).A]&0``@^P(Z-7]__^)A>A^__^%P`^$)P0``(N=Z'[__P^V`X3`
M=#J-=@"-O"<`````#[[0H>#20`"#.`$/A7\"``"A'--``(L`#[<$4"4'`0``
MA<!U`\8#7T,/M@.$P'70,<")A?!^__^+1;B`.`!T;^@+Y?__A<")QW1%Z.`6
M``")!"3HF!8``(G&Z-$6``")!"3HF18``(G#Z,(6``")!"3HBA8``(L0B70D
M"(E\)`2+`XD$)/]24(7`#X06`@``_X7P?O__BX7L?O__A<!U#XN5\'[__XM$
ME;B`.`!UD8N]['[__S'`B87P?O__A?\/A&<"``"+E>Q^__^)%"3H[1<``,<$
M)(AA0`")P^C?%P```<.+A>A^__^)!"3HSQ<``,<$)%1A0``!P^C!%P``C;0#
M``0``.@E%@``B00DZ/T5``")P^@6%@``B00DZ.X5``"+$(ET)`2+`XD$)/\2
MBY7H?O__B87D?O__B50D%+J(84``B50D$*$`4$``B40D#(N%['[__XE$)`BX
MC6%``(E$)`2+E>1^__^)%"3H_A8``(N%Y'[__XD$).BP%@``N#UA0`#HQN/_
M_XD$).A.%P``B40D!(M5"(L"B00DZ%WF__^%P(G&#X2]`@``Z![K__^%P'5!
MZ'45``")!"3H/14``(G#Z&85``")!"3H+A4``(L0N`"```")1"0(B70D!(L#
MB00D_U(\B87@?O__A<`/A7T"``"Z^F!``+B*8$``Z%KC___H)14``(D$).C-
M%```B</H%A4``(D$).B^%```BQ"+`[M484``B00D_U)HB5PD%+F684``B40D
M$*$`4$``B40D#(N5Y'[__XE,)`2)5"0(B10DZ!,6``"+E>1^__^X*F!``.CS
MXO__BX7D?O__B00DZ$7[__^+A>1^__^-9?1;7E]=PXVT)@````")%"2X!P$`
M`(E$)`3H+Q8``.E[_?__Z(44``")!"3H/10```^W0`8E`/```#T`0```#X7)
M_?__Z&04``")!"3H+!0``(G#Z%44``")!"3H'10``(L0N`(```")1"0(B7PD
M!(L#B00D_Q*%P`^%C_W__XD\).C7%0``B87L?O__Z7S]__^)!"3HI/K__XD\
M).B\%0``C67T6UY?7<.+?=B`/P`/A(W]__^0C;0F`````.CK$P``B00DZ*,3
M``")QNC<$P``B00DZ*03``")P^C-$P``B00DZ)43``"+$(ET)`B)?"0$BP.)
M!"3_4E"%P'0H_X7P?O__BXWL?O__A<D/A3#]__^+A?!^__^+?(78@#\`=9SI
M'/W__^B"$P``B00DZ#H3```/MT`&)0#P```]`$```'6[Z&43``")!"2^`@``
M`.@H$P``B</H41,``(D$).@9$P``BQ")="0(B7PD!(L#B00D_Q*%P'6%B3PD
MZ-P4``")A>Q^___I<O___Y"+1:@QR8F-\'[__X`X`'0ZZ"OA__^%P'0.B00D
MZ*\4``")A>A^____A?!^__^+E>A^__^%T@^%GOO__XN5\'[__XM$E:B`.`!U
MQKBD84``B87H?O__Z<;[__^+10B+,.DY_?__Z+<2``")!"3H?Q(``(G#Z*@2
M``")!"3H<!(``(L0N`(```")1"00N.[___^)1"0(N/____^)1"0,BX7@?O__
MB40D!(L#B00D_U(PZ&P2``")!"3H-!(``(G#Z%T2``")!"3H)1(``(L0N`8`
M``")1"0,C848?___B40D"(N%X'[__XE$)`2+`XD$)/]21("]&'___P!U#8"]
M&7___T,/A.@#``"X`2-%9[_PX=+#,?:)A1C___^XB:O-[S';B84<____N/[<
MNI@QR8F%(/___[AV5#(0B84D____B;TH____B;4L____B9TP____B8UT____
MB?:-O"<`````Z+L1``")!"3H@Q$``(G#Z*P1``")!"3H=!$``(L0N`"```")
M1"0,C848?___B40D"(N%X'[__XE$)`2+`XD$)/]21(7`B<8/C@$!``"-E1A_
M__^+A3#___^)\XF5W'[__XN5+/___XT,\HF-+/___SG1@]``B84P____B?#!
MZ!T!A3#___^+A73___^%P'1@OT`````IQSGW?@*)]XE\)`B-A"@T____B?.)
M!"2-E1A___\I^XE4)`3H(A(``(V%&'___P'XB87<?O__BX5T____`?B)A73_
M__^#^$`/A1W___^-A1C____HPN;__XGVC;4T____ZS"Z0````(/K0(E4)`B+
ME=Q^__^)-"2)5"0$Z,H1``"#A=Q^__]`C848____Z(CF__^#^S]_RXE<)`B+
MA=Q^__^)-"2)1"0$Z)T1``")G73____ILO[__^AM$```B00DZ#40``")P^A>
M$```B00DZ"80``"+$(N%X'[__XE$)`2+`XV=^'[__XD$)/]2$(N5+/___["`
MB[4P____B978?O__P>H#@^(_B(0J-/___T*#^C@/CKP!``"X0````(V]-/__
M_RG0B40D"(V4%33___\QP(D4)(E$)`3H^Q```(V%&/___^C0Y?___+D.````
M,<#SJP^VE=A^__^)\,'H&(B%;/___XGPP>@0B(5M____B?#!Z`B(A6[___^)
M\(V]>/___XB%;____XN%V'[__XG^B)5S____P>@8B(5P____BX78?O__P>@0
MB(5Q____BX78?O__P>@(B(5R____C848____Z%#E__^+E1C___^)T,'H&(@#
MB=#!Z!"(0P&)T,'H"(A#`HA3`XN5'/___XG0B%,'P>@8B$,$B=#!Z!"(0P6)
MT,'H"(A#!HN5(/___XG0B%,+P>@8B$,(B=#!Z!"(0PF)T,'H"(A#"HN5)/__
M_XG0B%,/P>@8B$,,B=#!Z!"(0PV)T,'H"(A##HN5*/___XG0B%,3P>@8B$,0
MB=#!Z!"(0Q&)T,'H"(A#$C';C78`C;PG``````^VA"OX?O__0XDT)(/&`HE$
M)`BXJV%``(E$)`3HSP\``(/[$W[:QD6@`+A484``B40D%(E\)!"A`%!``+ZP
M84``B40D#(N%Y'[__XET)`2)1"0(B00DZ7WY__^X.````"G0C905-/___XE$
M)`@QP(E$)`2)%"3H10\``.E:_O__@+T:?___00^%"_S__X"]&W___T,/A?[[
M__^`O1Q___](#X7Q^___@+T=?___10^%Y/O__^CW#0``B00DOP(```"^QO__
M_^BU#0``B</HW@T``(D$).BF#0``N?____^+$(E,)`R)?"00B70D"(N%X'[_
M_XE$)`2+`XD$)/]2,.BL#0``B00DZ'0-``")P^B=#0``B00DZ&4-``"+$+@I
M````B40D#(V%&'___XE$)`B+A>!^__^)1"0$BP.)!"3_4D2X5&%``(V5&'__
M_XE$)!2)5"00Z=W^__^-M@````!5B>575E.![$P!``"+=0B%]G0(BT4(@#@`
M=0B-9?1;7E]=PXD$).BU#@``C;`"`0``Z!H-``")!"3H\@P``(G#Z`L-``")
M!"3HXPP``(L0B70D!(L#N[]A0`")!"3_$HM-"(F%Q/[__XE,)`B)7"0$B00D
MZ!@.``"-A<C^__^)1"0$BXW$_O__B0PDZ+`-``")A<#^__]`=(*Y7````(V%
MW/[__XE,)`2)!"3H0`T``(7`#X2$`@``C87<_O__B40D!(N-Q/[__XD,).@0
M#0``N,9A0`")1"0$BX7$_O__B00DZ-D-``"%P(G##X34`0``_+@#````O\9A
M0`")WHG!\Z9T'+@$````O\EA0`")WHG!\Z8/A:L!``"-M@````"-C<C^__^)
M3"0$BX7`_O__B00DZ.@,``"%P`^%S@```+A<````C8W<_O__B40D!(D,).B9
M#```A<`/A#D!``"-C=S^__^)3"0$BX7$_O__B00DZ&D,``"XQF%``(E$)`2+
MC<3^__^)#"3H,@T``(7`B<-T+?RX`P```+_&84``B=Z)P?.F#X1U____N`0`
M``"_R6%``(G>B<'SI@^$7____XN%R/[__S'2P>@$@WT,``^5PH7"=%FX`0``
M`(E$)`2+A<3^__^)!"3H$O[__XV-R/[__XE,)`2+A<#^__^)!"3H&@P``(7`
M#X0R____BXW`_O__B0PDZ/0+``"+10B)!"3HV0L``(UE]%M>7UW#D(V-W/[_
M_S';B0PDZ!`-``"#[`2)QHUT)@"-O"<`````BX7$_O__B00DZ-(+``"%P`^$
MNO[__XG80X/X"0^/KO[__X7V=-J)-"3HP@P``(N%Q/[__X/L!(D$).BA"P``
MA<!UT^F(_O__C87<_O__B40D#(M-"+C-84``B40D!(E,)`B+A<3^__^)!"3H
MT`L``.FR_O__BX7(_O__,=+!Z`2#?0P`#Y7"A<(/A?C^__^-C=S^__\QVXD,
M).AA#```@^P$B<:+A<3^__^)!"3H+@L``(7`#X06_O__B=A#@_@)#X\*_O__
MA?9TVHDT).@>#```BX7$_O__@^P$B00DZ/T*``"%P'73Z>3]__^-C=S^__^Z
MS6%``(E,)`R+10B)5"0$B40D"(N-Q/[__XD,).@L"P``Z6?]__^-M"8`````
M58GE@^P8B5WTBUT(B77XB7W\B1PDZ";=__^)!"2)Q^C,W/__B<;H5=___X7`
M="&%VW0=@#L`=!B)-"2XB&%``(E$)`3H!PL``#GP=!"-=@"+7?2+=?B+??R)
M[%W#B1PDN`$```")1"0$Z"+\__^)/"0QP(E$)`3H%/S__^O2B?95B>53@^P4
MZ%0)``")!"3H[`@``(L`BU@$Z$()``")!"3HR@@``(L`B4,@Z#`)``")!"3H
MR`@``(L`BU@$Z!X)``")!"3HE@@``(L`#[=`$(E#).@("0``B00DZ*`(``"+
M`(M8!.CV"```B00D,<FZ5&%``(E,)`B)5"0$Z$\(``")0RCHUP@``(D$).AO
M"```BP"+6`3HQ0@``(D$).@="```BP")0RSHLP@``(D$).A+"```BP"+6`3H
MH0@``(D$).CI!P``BP")0S#HCP@``(D$).@G"```BP"+0`3'0#0`````@\04
M6UW#D(UT)@!5B>6#[!CH90@``(D$)+K_____B50D!.B4!P``Z$\(``")!"0Q
MR;I0/$``B4PD"(E4)`3H:`<``,G#C;8`````58GE5S'_5E.#[!SH(`@``(D$
M).@X!P``Q@`!N&Y@0`#H*];__X7`=`F`.#$/A!\"``#H2=S__^CT!P``B00D
MN0H```"Z`0```(E,)`R^TV%``(E4)`B)="0$Z.$&``"%P`^$EP```(L`O@$`
M``"+%5#!0`"+0"`YUHM`$(E%\'URZPV0D)"0D)"0D)"0D)"0Z)L'``")!"2-
M5O\QVXE4)`B+5?")7"0,B50D!.A_!@``A<")PP^$B@(``(L`]D`*!`^$F0$`
M`(L`BP")1"0$H6#!0`"+!+")!"3HH0@``(7`#X5>`@``1T:+%5#!0``YUGR=
MC4+_.?@/A*(!``#H+0<``(D$)+L!````N=AA0`")7"0(O@0```")="0,B4PD
M!.@:!@``A<")PW0RZ/\&``"ZVF%``(E4)`B+$XM2((L2B00DB50D!.BS!0``
MBP.+0""+`/9`"4`/A<H!``#HS08``(D$)+OC84``OP0```")7"0$O@$```")
M?"0,B70D".BZ!0``A<")PW0PN#-@0`#HNM3__X7`B<8/A#(!``#HBP8``(ET
M)`B+$XM2((L2B00DB50D!.A$!0``Z&\&``")!"3HAP4``,8``.A?!@``B00D
MZ`<%``#'``````"X*F!``.AGU/__HT#!0`"%P`^$D0```.@U!@``B00DZ,T$
M``")P^@F!@``B00DZ+X$``"+$+GM`0``H4#!0`")3"0(B40D!(L#B00D_Q*%
MP(G&#Y7",<"#_A$/E<"%PG0)@_[_#X4=`0``@\0<6UY?7<.`>`$`#X3<_?__
MZ=+]___HRP4``#'2N0(```")3"0,B50D"(L3B00DB50D!.B>!```Z43^__^A
M8,%``(D$).A<[?__HT#!0`#I6/___XGVO@$````YU@^-4?[__XUV`.A[!0``
MB00DBU7P1HE4)`3H2P0``#LU4,%``'SCZ2S^___H&=;__X7`B<9T<^A.!0``
MB70D"(L3BU(@BQ*)!"2)5"0$Z`<$``#H,@4``(D$).@*!0``B</H(P4``(D$
M).C[!```BQ")="0$BP.)!"3_4@CIE/[__^@#!0``BQ.+4B"+$HD$)(E4)`3H
ML`,``.D9_O__BQ50P4``Z:/]___HVP0``(L58,%``(L2B50D".E#_O__B70D
M#*%`P4``B40D"*%@P4``BP#'!"3H84``B40D!.@V`P``C;8`````58GE4X/L
M%+N`/4``Z(\$``")!"3HM]'__^B"!```B00DNE1A0`"Y-F)``(E4)`R)3"0$
MB5PD".AT!```B</H700``(D$)+I484``B5PD!(E4)`CH&`,``(/$%%M=PXGV
M5;@0````B>564X/L((/D\.B["@``Z"8'``"-10R)1"0$C44(B00D_Q5LTD``
MQP0D`````.B'`@``@#@`=2WH;0(``*,PP4``A<`/A'`!``")!"3H2`(``.CC
M`P``B00DZ"L"``#'``````#HT`,``(D$).@(`@``@`@"Z,`#``")!"3H^`$`
M`(`(`8M5"(U"!3W___\_#X=3`0``C025%````+L!````B00DZ,`!``"C8,%`
M`(MU#(G!BP;'001+8D``QT$(8&)``(D!N`0```#'00Q.8D``HU#!0`"+10@Y
MPWP+ZR:+#6#!0`"+=0R+%5#!0`"+!)X!VHE$D?Q#BT4(.<-\X(L-8,%``(L=
M4,%``#'2,?8!V(E4@?RA8,%``+D004``B70D$(M="(E,)`2)1"0,H5#!0``!
MV$B)1"0(H3#!0`")!"3H$@$``(7`B<-T6Z$PP4``B00DZ-\```"X?F!``.CU
MT/__A<!U)*%`P4``A<!U$[@J8$``Z-[0__^C0,%``(7`=`B)!"3HS?C__Z$P
MP4``B00DZ)````#_%7#20`"-9?B)V%M>7<.A,,%``(D$).B4````B</KE.A[
M`@``B00DZ","``")P^AL`@``B00DZ!0"``"+$+@!````B40D!(L#B00D_U((
MH?C10`")!"3HU````)"0D)#_)6S20`"0D```````````_R5PTD``D)``````
M`````/\E^-%``)"0``````````#_)8320`"0D```````````_R6`TD``D)``
M`````````/\EC-)``)"0``````````#_)8C20`"0D```````````_R5<TD``
MD)```````````/\E&-)``)"0``````````#_)2#20`"0D```````````_R5\
MTD``D)```````````/\E>-)``)"0``````````#_)?S10`"0D```````````
M_R5`TD``D)```````````/\E`-)``)"0``````````#_)1#20`"0D```````
M````_R50TD``D)```````````/\E:-)``)"0``````````#_)3S20`"0D```
M````````_R5DTD``D)```````````/\E.-)``)"0``````````#_)4S20`"0
MD```````````_R4TTD``D)```````````/\E8-)``)"0``````````#_)432
M0`"0D```````````_R4<TD``D)```````````/\E%-)``)"0``````````#_
M)5320`"0D```````````_R4LTD``D)```````````/\E*-)``)"0````````
M``#_)2320`"0D```````````_R4,TD``D)```````````/\E,-)``)"0````
M``````#_)0320`"0D```````````_R4(TD``D)```````````/\E=-)``)"0
M``````````#_)4C20`"0D```````````_R58TD``D)```````````/\E[-)`
M`)"0``````````#_)?320`"0D```````````_R7DTD``D)```````````/\E
M2--``)"0``````````#_)>C20`"0D```````````_R4DTT``D)``````````
M`/\EW-)``)"0``````````#_)5C30`"0D```````````_R50TT``D)``````
M`````/\E(--``)"0``````````#_)?C20`"0D```````````_R4`TT``D)``
M`````````/\E*--``)"0``````````#_)?S20`"0D```````````_R44TT``
MD)```````````/\E1--``)"0``````````#_)3S30`"0D```````````_R5@
MTT``D)```````````/\E3--``)"0``````````#_)5330`"0D```````````
M_R5HTT``D)```````````/\E9--``)"0``````````#_)4#30`"0D```````
M````_R5<TT``D)```````````/\E$--``)"0``````````#_)<S20`"0D```
M````````_R70TD``D)```````````/\EJ-)``)"0``````````#_)<#20`"0
MD```````````_R6PTD``D)```````````/\EO-)``)"0``````````#_);C2
M0`"0D```````````_R68TD``D)```````````%6Y@+-``(GEZQ2-M@````"+
M402+`8/!"`&"``!``('Y@+-``'+J7<.0D)"0D)"0D%6)Y=OC7<.0D)"0D)"0
MD)!5B>6#[`BA0%!``(,X`'07_Q"+#4!00`"+402-002C0%!``(72=>G)PXVT
M)@````!5B>53@^P$H?!,0`"#^/]T*87`B<-T$XGVC;PG`````/\4G?!,0`!+
M=?;'!"0@2$``Z"K*__]96UW#,<"#/?1,0```ZPI`BQR%]$Q``(7;=?3KOHVV
M`````(V\)P````!5B>53@^P$BQV`P4``A=MU-:'P3$``N0$```")#8#!0`"#
M^/]T)(7`B<-T#HUT)@#_%)WP3$``2W7VQP0D($A``.BZR?__6%M=PS'`@SWT
M3$```.L*0(L4A?1,0`"%TG7TZ\.0D)"0D)"0D)"0D)"05:'PP4``B>5=BT@$
M_^&)]E6Z0@```(GE4P^WP(/L9(E4)`B-5:@QVXE4)`2)!"3_%;320`"Z'P``
M`+D!````@^P,A<!U!^L]`<E*>`Z`?"JH077T"<L!R4IY\H,[5'4'B=B+7?S)
MP\<$).2R0`"Z]P```+@4LT``B50D"(E$)`3HRP(``,<$)$BS0`"[\0```+D4
MLT``B5PD"(E,)`3HK0(``(VV`````(V\)P````!5B>575E.![+P```"+/?#!
M0`"%_W0(C67T6UY?7</'19A!04%!H<"R0`"-?9C'19Q!04%!QT6@04%!08E%
MN*'$LD``QT6D04%!0<=%J$%!04&)1;RAR+)``,=%K$%!04''1;!!04%!B47`
MH<RR0`#'1;1!04%!B47$H="R0`")1<BAU+)``(E%S*'8LD``B470H=RR0`")
M1=0/MP7@LD``9HE%V(D\)/\5K-)```^WP(/L!(7`#X5Q`0``QP0D5````.CY
M`0``A<")PP^$CP$``(D$)#')OE0```")3"0$B70D".@(_/__QT,$H$Q``+D!
M````QT,(($E``*&@P4``QP-4````BQ6DP4``QT,H`````(E#%*%04$``B5,8
MBQ544$``B4,<H;#!0`#'0RS_____B5,@B4,PH5A00`"+%5Q00`")0S2AP,%`
M`(E3.(L5Q,%``(E#/*'0P4``QT-$_____XE30(E#2(L59%!``*%@4$``B5-0
MNA\```")0TR)V"'(@_@!&<`D(`')!$&(A"I(____2GGGH<"R0`")A6C___^A
MQ+)``(F%;/___Z'(LD``B85P____H<RR0`")A73___^AT+)``(F%>/___Z'4
MLD``B85\____H=BR0`")18"AW+)``(E%A`^W!>"R0`!FB46(C85(____B00D
M_Q6DTD``#[?P@^P$A?9U0C'2A=)U'HD<).B3````B3PD_Q6LTD``@^P$#[?`
MZ"_]__^)PXD=\,%``(U#!*/@P4``C4,(HP#"0`"-9?1;7E]=PXGPZ`C]__\Y
MV(GR=;'KL>AK````D)"0D)"0D)"0D)!1B>&#P0@]`!```'(0@>D`$```@PD`
M+0`0``#KZ2G!@PD`B>")S(L(BT`$_^"0D)#_)?#20`"0D```````````_R4T
MTT``D)```````````/\E.--``)"0``````````#_)2S30`"0D```````````
M_R6TTD``D)```````````/\EK-)``)"0``````````#_):320`"0D```````
M````58GE7>GGQ?__D)"0D)"0D/_____@3$```````/____\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````&!```)@0`#_____`````%90``"WLD``
M``````````#_____`````````````````$````````````````````!-0```
M````````````````````_____P````#_____`````/____\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!<`#L`<&5R
M;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!005)?5$5-4`!0
M05)?4%)/1TY!344`+@`E<R5S)7,`````7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("```%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P
M`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``,0!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!
M3CT`3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(`%!!5$@`
M1%E,1%],24)205)97U!!5$@``$,Z7%1%35``+W1M<`!435!$25(`5$5-4$1)
M4@!414U0`%1-4`!54T52`%5315).04U%`'!A<BT`)7,E<R5S)7,`)7,E<W1E
M;7`M)74E<P!365-414T`)3`R>``E<R5S8V%C:&4M)7,E<P`E<UPJ+BH`7"X`
M7"XN`"5S7"5S`$%21U8`&`!P97)L+F5X90`P`````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@
M86)O<G1I;F<@=VET:"`E:2X*`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"UE`"TM
M`````````````````````",A+W5S<B]B:6XO<&5R;`H*979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P[
M"@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@
M870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3D*
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!U;FQI;FL@0'1M<&9I;&4["B`@
M("!R;61I<B`D<&%R7W1E;7`["B`@("`D<&%R7W1E;7`@/7X@<WM;7EQ<+UTJ
M6UQ<+UT_)'U[?3L*("`@(')M9&ER("1P87)?=&5M<#L*?2!]"@I"14=)3B![
M"B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I
M.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!
M4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B
M?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM0
M05)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@
M("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*
M?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G
M;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE
M8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S
M=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D
M<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D
M8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@
M("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I
M;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL
M92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M
M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*
M("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@
M("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM
M;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T
M96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!
M4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,
M24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E
M*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@
M("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@
M("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@
M("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C
M(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*
M("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B
M('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@
M(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@
M;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@
M?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E
M86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE
M>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME
M>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@
M("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@
M("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I
M;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H
M+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?
M=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@
M("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*
M("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*
M("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D
M9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*
M("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I
M;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER
M92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO
M=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI
M;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T
M:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@
M("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O
M(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE
M;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E
M("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T
M;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG
M('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D
M(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB
M7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U
M;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@
M('9E<FEF>5]P87(*("`@("D["B`@("!W:&EL92`H0$%21U8I('L*("`@("`@
M("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@('5N
M<VAI9G0@0$E.0RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H
M:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D
M,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD
M;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE
M="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*
M("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS
M:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L
M971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D[
M"B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@
M("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"GT*"B,@6%A8("TM(&%D9"`M
M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/
M*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER
M92!!<F-H:79E.CI::7`["B`@("!]"@H*("`@(&UY("1P87(@/2!S:&EF="A`
M05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2![
M"B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO
M="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2([
M"B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@
M("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@
M("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L
M("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@
M8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@
M9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@
M("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN
M;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD
M9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@
M)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@
M("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I
M"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@
M("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@
M("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@
M("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H
M)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R
M:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@
M("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH@("`@
M("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R
M="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@
M("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!]
M(&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@
M("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@*"1#;VYF:6=[
M7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN8R!]"@H@("`@
M("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`D9FEL97-[
M)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@
M=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@
M("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY
M("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>
M+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B
M(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N
M+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*
M("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@
M("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@
M("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@
M("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R
M('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T
M;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q
M(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@
M("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C
M;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W
M('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R
M(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@
M)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*
M("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4[
M"B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]
M"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C
M:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2
M(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R
M97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&
M:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@
M("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@
M("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY
M("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PH@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@(&]U=',H<7$H17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@
M("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@
M;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\[
M"B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ
M4&%T:#L*("`@(`H)1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E
M<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB
M.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R
M.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@
M("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER
M92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R
M97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R
M97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I
M;B!M>6QD<B]M:W1M<&1I<BYC"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF
M("@D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@
M("`@("`@;F5X="!U;FQE<W,@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED
M.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@
M(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@
M("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@
M("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@
M("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@
M+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@
M("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@
M('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*
M("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@
M;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I
M.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N
M86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D
M9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@
M(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM
M;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@IS=6(@
M7W-E=%]P<F]G;F%M92!["B`@("!I9B`H)$5.5GM005)?4%)/1TY!345](&%N
M9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@
M("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@
M;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*
M("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@
M("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@
M(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@
M("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@
M("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I
M"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]
M"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A8
M6"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z("1%3E9[
M4%=$?3L*("`@("1P=V0@/2!@<'=D8"!I9B`A9&5F:6YE9"`D<'=D.PH@("`@
M8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#
M;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN
M:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@
M05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@
M?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@
M("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@
M("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@
M('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@
M("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M
M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R
M:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@
M("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L
M:6YE(#DT,@H*7U]%3D1?7PH`<&%R+G!L````+4Q)0D=#0U<S,BU%2"TS+5-*
M3$HM1U1(4BU-24Y'5S,R````=S,R7W-H87)E9'!T<BT^<VEZ92`]/2!S:7IE
M;V8H5S,R7T5(7U-(05)%1"D`````+BXO+BXO9V-C+3,N-"XU+V=C8R]C;VYF
M:6<O:3,X-B]W,S(M<VAA<F5D+7!T<BYC`````$=E=$%T;VU.86UE02`H871O
M;2P@<RP@<VEZ96]F*',I*2`A/2`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!\T`````````````!H
MV0``^-$``!S1`````````````'C9``"8T@``*-$`````````````J-D``*32
M``!0T0````````````#`V0``S-(``&#1`````````````%S:``#<T@``````
M````````````````````````````<-,``(33``"<TP``K-,``+S3``#,TP``
MX-,``/33```,U```)-0``#C4``!8U```=-0``(C4``"8U```K-0``,#4``#0
MU```X-0``/C4```(U0``'-4``##5``!`U0``4-4``&#5``!XU0``E-4``*C5
M``"XU0``S-4``.#5``#TU0``!-8``!C6```HU@``--8``$36````````````
M`%#6`````````````&#6``!LU@``?-8``(C6``"8U@``J-8``,#6``#4U@``
M``````````#TU@```-<`````````````#-<``!S7```LUP``/-<``$S7``!@
MUP``;-<``'C7``"(UP``F-<``*37``"PUP``O-<``,37``#0UP``W-<``.C7
M``#TUP```-@```S8```8V```(-@``"S8```TV```0-@``$S8``!8V```9-@`
M`'#8``!\V```B-@``)38``"@V```K-@``+C8``#$V`````````````!PTP``
MA-,``)S3``"LTP``O-,``,S3``#@TP``]-,```S4```DU```.-0``%C4``!T
MU```B-0``)C4``"LU```P-0``-#4``#@U```^-0```C5```<U0``,-4``$#5
M``!0U0``8-4``'C5``"4U0``J-4``+C5``#,U0``X-4``/35```$U@``&-8`
M`"C6```TU@``1-8`````````````4-8`````````````8-8``&S6``!\U@``
MB-8``)C6``"HU@``P-8``-36`````````````/36````UP`````````````,
MUP``'-<``"S7```\UP``3-<``&#7``!LUP``>-<``(C7``"8UP``I-<``+#7
M``"\UP``Q-<``-#7``#<UP``Z-<``/37````V```#-@``!C8```@V```+-@`
M`#38``!`V```3-@``%C8``!DV```<-@``'S8``"(V```E-@``*#8``"LV```
MN-@``,38````````!0!03%]M96UO<GE?=W)A<`````"/`%!E<FQ?1V1O7W5N
M9'5M<%]P='(```"C`%!E<FQ?241I<E]P='(`I0!097)L7TE,24]?<'1R`*@`
M4&5R;%])365M7W!T<@"L`%!E<FQ?25!R;V-?<'1R`````,(`4&5R;%])8V]M
M<&-V7W!T<@``WP!097)L7TEE=F%L7W)O;W1?<'1R````X@!097)L7TEE>&ET
M7V9L86=S7W!T<@``&0%097)L7TEL:6YE<W1R7W!T<@!-`5!E<FQ?27!E<FQ?
M9&5S=')U8W1?;&5V96Q?<'1R`.0!4&5R;%]48W5R<W1A8VMI;F9O7W!T<@``
M``#S`5!E<FQ?5&EN7V5V86Q?<'1R`/\!4&5R;%]4;W!?<'1R``!,`E!E<FQ?
M5'-T871B=69?<'1R`%`"4&5R;%]4=&%I;G1E9%]P='(`8`)097)L7V%V7V9E
M=&-H`&8"4&5R;%]A=E]S:&EF=`"I`E!E<FQ?8W)O86M?;F]C;VYT97AT``#+
M`E!E<FQ?9&]U;G=I;F0`X0)097)L7V=E=%]C;VYT97AT`````U!E<FQ?9W9?
M9F5T8VAP=@```&X#4&5R;%]M9U]S970```"J`U!E<FQ?;F5W4U9P=@``M`-0
M97)L7VYE=UA3`````.H#4&5R;%]S869E<WES;6%L;&]C`````/<#4&5R;%]S
M879E7V1E<W1R=6-T;W)?>``````Q!%!E<FQ?<W9?,G!V7V9L86=S`'\$4&5R
M;%]S=E]S971P=@#<!%!E<FQ?=VEN,S)?:6YI=````-T$4&5R;%]W:6XS,E]T
M97)M````WP1B;V]T7T1Y;F%,;V%D97(```#@!'!E<FQ?86QL;V,`````Y@1P
M97)L7V-O;G-T<G5C=`````#G!'!E<FQ?9&5S=')U8W0`Z`1P97)L7V9R964`
MZ@1P97)L7W!A<G-E`````.L$<&5R;%]R=6X``/4`1V5T57-E<DYA;65!```!
M`$%D9$%T;VU!``";`$5X:710<F]C97-S````KP!&:6YD071O;4$`U0!&<F5E
M3&EB<F%R>0```-P`1V5T071O;4YA;65!``!-`4=E=$UO9'5L949I;&5.86UE
M00````!/`4=E=$UO9'5L94AA;F1L94$``.`"4V5T56YH86YD;&5D17AC97!T
M:6]N1FEL=&5R````40!?<W1R9'5P````50!?<W1R;FEC;7``)P!?7V=E=&UA
M:6YA<F=S`#``7U]M8E]C=7)?;6%X```\`%]?<%]?96YV:7)O;@``/@!?7W!?
M7V9M;V1E`````%``7U]S971?87!P7W1Y<&4`````;P!?87-S97)T````>0!?
M8V5X:70`````KP!?9FEN9&-L;W-E`````+``7V9I;F1F:7)S=`````"S`%]F
M:6YD;F5X=`"Y`%]F;6]D90````"\`%]F<')E<V5T``#I`%]I;V(``.L`7VES
M8W1Y<&4``%D!7VUK9&ER`````%X!7V]N97AI=````&<!7W!C='EP90```'(!
M7W)M9&ER`````(0!7W-E=&UO9&4``+@!7W5N;&EN:P```!4"86)O<G0`'`)A
M=&5X:70`````/P)F<F5E``!R`FUA;&QO8P````!X`FUE;6-P>0````!Y`FUE
M;6UO=F4```!Z`FUE;7-E=`````"0`G-I9VYA;`````"3`G-P<FEN=&8```"8
M`G-T<F-H<@````"9`G-T<F-M<`````";`G-T<F-P>0````"?`G-T<FQE;@``
M``"B`G-T<FYC<'D```"F`G-T<G-T<@````"H`G-T<G1O:P``````T````-``
M``#0````T````-````#0````T````-````#0````T````-````#0````T```
M`-````#0````T````-````#0````T````-````#0````T````-````#0````
MT````-````#0````T````-````#0````T````-````#0````T````-````#0
M````T````-```'!E<FPU."YD;&P``!30``!!1%9!4$DS,BY$3$P`````*-``
M`"C0```HT```*-```"C0```HT```*-```"C0``!+15).14PS,BYD;&P`````
M/-```#S0``!M<W9C<G0N9&QL``!0T```4-```%#0``!0T```4-```%#0``!0
MT```4-```%#0``!0T```4-```%#0``!0T```4-```%#0``!0T```4-```%#0
M``!0T```4-```%#0``!0T```4-```%#0``!0T```4-```%#0``!0T```4-``
M`%#0``!0T```4-```%#0``!0T```4-```%#0``!M<W9C<G0N9&QL````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````;G*20`````````,``P```"@``(`.````N```@!`````(`0"``````&YR
MDD`````````$``$```!8``"``@```'```(`#````B```@`0```"@``"`````
M`&YRDD`````````!``D$```X`0```````&YRDD`````````!``D$``!(`0``
M`````&YRDD`````````!``D$``!8`0```````&YRDD`````````!``D$``!H
M`0```````&YRDD`````````"`&4```#8``"`9@```/```(``````;G*20```
M``````$`"00``'@!````````;G*20`````````$`"00``(@!````````;G*2
M0`````````$``0```"`!`(``````;G*20`````````$`"00``)@!``"HX0``
M:`4`````````````$.<``*@(`````````````+CO``!H!0`````````````@
M]0``J`@`````````````R/T``"(``````````````.S]```B````````````
M```0_@``7@(`````````````*````!`````@`````0`(`````````0``````
M`````````0````$```8&!@`$!`0``@("``````!"0D(`G9V=`&YN;@"!@8$`
ML;&Q`/___P!S<W,`GY^?`%A86`"RLK(`_?W]`&MK:P#\_/P`U]?7`!86%@#:
MVMH`EI:6`(Z.C@!&1D8`R\O+``L+"P"@H*``_O[^`,G)R0#!P<$``P,#`!$1
M$0"3DY,`L[.S`.[N[@#T]/0`X^/C`.7EY0"BHJ(`NKJZ`*^OKP`'!P<`<7%Q
M`+6UM0#U]?4`B8F)`(J*B@`T-#0`Z.CH`#4U-0!:6EH`M[>W`-C8V`#0T-``
M'1T=``P,#`"/CX\`OKZ^`&UM;0`)"0D`FYN;`"\O+P#-S<T`V=G9`!D9&0!-
M34T`1$1$`%!04``\/#P`9&1D`,+"P@`R,C(`"`@(``T-#0`/#P\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```!04%!04%!04%!04%!04$!`0$U0",%03%#04%$12X!`0$!`0$!!0$\%Q<!
M`1,!`0$!`0$!`14!`285`0$/`0$!`0$!`0$3`1$!!34!)@$!`0$!`0$!(A(0
M,0\%`2`!`0$!`0$!`1`*("(5%2XA+@$!`0$!'R`A$"(0(R,E)B<!`0$!)1`0
M$!`0$!`0$!=%`0$!01`0$!`0$!`0$!`0%P$!`0\0$!40$!`0$!`0$`$!`0$2
M$!`3'Q`0$!`0$`<!`0$!(!`0$`$/$!`0$!$!`0$!`0<@$`H!`040$!`Q`0$!
M`0$!`0$!`0$!004/`0$!`0$!`0$!`0$!`0$!`0$!`0$!@`$``,`!``#@`P``
M\`,``/`#``#P`P``X`,``,`!``"``0``@`$``(`#``"``P````<````'``".
M#P``_Q\``"@````@````0`````$`"`````````0```````````````$````!
M`````````0$!``("`@`#`P,`!`0$``4%!0`&!@8`!P<'``@("``)"0D`"@H*
M``L+"P`,#`P`#0T-``X.#@`/#P\`$!`0`!$1$0`2$A(`$Q,3`!04%``5%14`
M%A86`!<7%P`8&!@`&1D9`!H:&@`;&QL`'!P<`!T='0`>'AX`'Q\?`"`@(``A
M(2$`(B(B`",C(P`D)"0`)24E`"8F)@`G)R<`*"@H`"DI*0`J*BH`*RLK`"PL
M+``M+2T`+BXN`"\O+P`P,#``,3$Q`#(R,@`S,S,`-#0T`#4U-0`V-C8`-S<W
M`#@X.``Y.3D`.CHZ`#L[.P`\/#P`/3T]`#X^/@`_/S\`0$!``$%!00!"0D(`
M0T-#`$1$1`!%144`1D9&`$='1P!(2$@`24E)`$I*2@!+2TL`3$Q,`$U-30!.
M3DX`3T]/`%!04`!145$`4E)2`%-34P!45%0`5555`%965@!75U<`6%A8`%E9
M60!:6EH`6UM;`%Q<7`!=75T`7EY>`%]?7P!@8&``86%A`&)B8@!C8V,`9&1D
M`&5E90!F9F8`9V=G`&AH:`!I:6D`:FIJ`&MK:P!L;&P`;6UM`&YN;@!O;V\`
M<'!P`'%Q<0!R<G(`<W-S`'1T=`!U=74`=G9V`'=W=P!X>'@`>7EY`'IZ>@![
M>WL`?'Q\`'U]?0!^?GX`?W]_`("`@`"!@8$`@H*"`(.#@P"$A(0`A86%`(:&
MA@"'AX<`B(B(`(F)B0"*BHH`BXN+`(R,C`"-C8T`CHZ.`(^/CP"0D)``D9&1
M`)*2D@"3DY,`E)24`)65E0"6EI8`EY>7`)B8F`"9F9D`FIJ:`)N;FP"<G)P`
MG9V=`)Z>G@"?GY\`H*"@`*&AH0"BHJ(`HZ.C`*2DI`"EI:4`IJ:F`*>GIP"H
MJ*@`J:FI`*JJJ@"KJZL`K*RL`*VMK0"NKJX`KZ^O`+"PL`"QL;$`LK*R`+.S
MLP"TM+0`M;6U`+:VM@"WM[<`N+BX`+FYN0"ZNKH`N[N[`+R\O`"]O;T`OKZ^
M`+^_OP#`P,``P<'!`,+"P@##P\,`Q,3$`,7%Q0#&QL8`Q\?'`,C(R`#)R<D`
MRLK*`,O+RP#,S,P`S<W-`,[.S@#/S\\`T-#0`-'1T0#2TM(`T]/3`-34U`#5
MU=4`UM;6`-?7UP#8V-@`V=G9`-K:V@#;V]L`W-S<`-W=W0#>WMX`W]_?`.#@
MX`#AX>$`XN+B`./CXP#DY.0`Y>7E`.;FY@#GY^<`Z.CH`.GIZ0#JZNH`Z^OK
M`.SL[`#M[>T`[N[N`._O[P#P\/``\?'Q`/+R\@#S\_,`]/3T`/7U]0#V]O8`
M]_?W`/CX^`#Y^?D`^OKZ`/O[^P#\_/P`_?W]`/[^_@#___\`-#0T/#P\/#P\
M/#P\/#P\/#P\/#P\/#P\+`P$!`0$!`1<M-34U-34U-34U-3<U-34U-34U-34
MU-2T-%$$!`0$!&3,[/3T]/ST_/3T]/ST_/3\]/S\_/3T[,0T45$$!`0$9,3D
M[/3T]/3T]/3T]/3T]/3T]/3T].SLO#1145$$!`1DQ.3L[.SD[.SLY.3DY.SL
MY.SD[.SL[.2\-%%145$$!&2\Y.SLK(RLU,24E)R4C(R4E)2<G)SLW+PT45%1
M45$$9+S<Y.SDQ%&4K&3DI$PT+%S$S%&TU.3<O#1145%145%DO-SDY.SDY%&$
M=.2,;*2<;(R\=*S4Y-R\-`0$!`0$!&2\W.3D[.3DO%&,U-2,K,QTS-RD4<3D
MW+PT!`0$!`0$9+S<Y.3DY.3<C'R<M'R$G&S,Y+QTQ.3<M#0$!`0$!`1<O-S<
MY.3DY-2<I%R4C,P\E&3,O(Q1W-2T-`0$!`0$!&2TU-S<W.3<C(RL++RTS%K$
M9)QLE*3<U+0T!`0$!`0$7+34W-SDW-QTE-1,I/2,/-1TE'2<3-S,M#0$!`0$
M!`1DM-3<W-SDW'11]'2$[,QDY'QLI+1LI-2T-`0$!`0$!&2TS-S<S'R,A+3\
MS,3\]+3\O&3,K(11O*PT!`0$!`0$7+3,U,R,I-S<[/S\_/S\]/SLM.RL?)11
MK#0$!`0$!`1<K,S,;)ST_/S\_/S\_/S\_/S\_,24C%&L-`0$!`0$!%RLQ+Q\
MY/S\_/S\_/S\_/S\_/S\[,RL4:PT!`0$!`0$7*RT3,3\_/SL]/S\_/S\_/S\
M_/STO%'$K#0$!`0$!`1<K+1,U/S\]+3<_/S\_/S\_/S\_,Q1S,2D-`0$!`0$
M!%RLQ*11_/S\M)ST_/S\_/S\_/STE%',Q*0L!`0$!`0$7*2D483L_/S,9+3L
M_/S\_/S\_-1LK,R\I#0$!`0$!`1<I&1TO/3\_,11A)SD_/S\_/SDC%',S,2D
M-`0$!`0$!%RD;(SD]/S\G%',493L_/S\_+QTS,S$O)PL!`0$!`0$7*2L9%QD
MI*11K,S$=)3D]/SD4;S,S,2\G#0$!`0$!`1<I+2\O(Q14<3$S,RL47Q\E&Q\
MO,S$Q+R<+`0$!`0$!%R<O,3$Q,3$Q,3$Q,3$45%14;S$Q,3$M)PT!`0$!`0$
M5)RTQ,3$Q,3$Q,3$Q,3$Q,3$Q,3$Q+RTG"P$!`0$!`14G+S$Q+R\O+R\O+R\
MO+R\O+R\O+R\O+2<+`0$!`0$!%R<M,2\M+2TM+2TM+2TM+2TM+2TM+2TK)PL
M!`0$!`0$5(24G)R4E)24E)24E)24E)24E)24E)24A"0$!`0$!`1$5%Q<7%Q<
M7%Q<7%Q<7%Q<7%Q<7%Q<7%Q4-`0$!`0$!````#\````?````#P````<````#
M`````0`````````_````/P```#\````_````/P```#\````_````/P```#\`
M```_````/P```#\````_````/P```#\````_````/P```#\````_````/P``
M`#\````_````/P```#\````_*````!`````@`````0`(`````````0``````
M`````````0````$```8&!@`$!`0``@("``````!"0D(`G9V=`&YN;@"!@8$`
ML;&Q`/___P!S<W,`GY^?`%A86`"RLK(`_?W]`&MK:P#\_/P`U]?7`!86%@#:
MVMH`EI:6`(Z.C@!&1D8`R\O+``L+"P"@H*``_O[^`,G)R0#!P<$``P,#`!$1
M$0"3DY,`L[.S`.[N[@#T]/0`X^/C`.7EY0"BHJ(`NKJZ`*^OKP`'!P<`<7%Q
M`+6UM0#U]?4`B8F)`(J*B@`T-#0`Z.CH`#4U-0!:6EH`M[>W`-C8V`#0T-``
M'1T=``P,#`"/CX\`OKZ^`&UM;0`)"0D`FYN;`"\O+P#-S<T`V=G9`!D9&0!-
M34T`1$1$`%!04``\/#P`9&1D`,+"P@`R,C(`"`@(``T-#0`/#P\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```!04%!04%!04%!04%!04$!`0$U0",%03%#04%$12X!`0$!`0$!!0$\%Q<!
M`1,!`0$!`0$!`14!`285`0$/`0$!`0$!`0$3`1$!!34!)@$!`0$!`0$!(A(0
M,0\%`2`!`0$!`0$!`1`*("(5%2XA+@$!`0$!'R`A$"(0(R,E)B<!`0$!)1`0
M$!`0$!`0$!=%`0$!01`0$!`0$!`0$!`0%P$!`0\0$!40$!`0$!`0$`$!`0$2
M$!`3'Q`0$!`0$`<!`0$!(!`0$`$/$!`0$!$!`0$!`0<@$`H!`040$!`Q`0$!
M`0$!`0$!`0$!004/`0$!`0$!`0$!`0$!`0$!`0$!`0$!@`$``,`!``#@`P``
M\`,``/`#``#P`P``X`,``,`!``"``0``@`$``(`#``"``P````<````'``".
M#P``_Q\``"@````@````0`````$`"`````````0```````````````$````!
M`````````0$!``("`@`#`P,`!`0$``4%!0`&!@8`!P<'``@("``)"0D`"@H*
M``L+"P`,#`P`#0T-``X.#@`/#P\`$!`0`!$1$0`2$A(`$Q,3`!04%``5%14`
M%A86`!<7%P`8&!@`&1D9`!H:&@`;&QL`'!P<`!T='0`>'AX`'Q\?`"`@(``A
M(2$`(B(B`",C(P`D)"0`)24E`"8F)@`G)R<`*"@H`"DI*0`J*BH`*RLK`"PL
M+``M+2T`+BXN`"\O+P`P,#``,3$Q`#(R,@`S,S,`-#0T`#4U-0`V-C8`-S<W
M`#@X.``Y.3D`.CHZ`#L[.P`\/#P`/3T]`#X^/@`_/S\`0$!``$%!00!"0D(`
M0T-#`$1$1`!%144`1D9&`$='1P!(2$@`24E)`$I*2@!+2TL`3$Q,`$U-30!.
M3DX`3T]/`%!04`!145$`4E)2`%-34P!45%0`5555`%965@!75U<`6%A8`%E9
M60!:6EH`6UM;`%Q<7`!=75T`7EY>`%]?7P!@8&``86%A`&)B8@!C8V,`9&1D
M`&5E90!F9F8`9V=G`&AH:`!I:6D`:FIJ`&MK:P!L;&P`;6UM`&YN;@!O;V\`
M<'!P`'%Q<0!R<G(`<W-S`'1T=`!U=74`=G9V`'=W=P!X>'@`>7EY`'IZ>@![
M>WL`?'Q\`'U]?0!^?GX`?W]_`("`@`"!@8$`@H*"`(.#@P"$A(0`A86%`(:&
MA@"'AX<`B(B(`(F)B0"*BHH`BXN+`(R,C`"-C8T`CHZ.`(^/CP"0D)``D9&1
M`)*2D@"3DY,`E)24`)65E0"6EI8`EY>7`)B8F`"9F9D`FIJ:`)N;FP"<G)P`
MG9V=`)Z>G@"?GY\`H*"@`*&AH0"BHJ(`HZ.C`*2DI`"EI:4`IJ:F`*>GIP"H
MJ*@`J:FI`*JJJ@"KJZL`K*RL`*VMK0"NKJX`KZ^O`+"PL`"QL;$`LK*R`+.S
MLP"TM+0`M;6U`+:VM@"WM[<`N+BX`+FYN0"ZNKH`N[N[`+R\O`"]O;T`OKZ^
M`+^_OP#`P,``P<'!`,+"P@##P\,`Q,3$`,7%Q0#&QL8`Q\?'`,C(R`#)R<D`
MRLK*`,O+RP#,S,P`S<W-`,[.S@#/S\\`T-#0`-'1T0#2TM(`T]/3`-34U`#5
MU=4`UM;6`-?7UP#8V-@`V=G9`-K:V@#;V]L`W-S<`-W=W0#>WMX`W]_?`.#@
MX`#AX>$`XN+B`./CXP#DY.0`Y>7E`.;FY@#GY^<`Z.CH`.GIZ0#JZNH`Z^OK
M`.SL[`#M[>T`[N[N`._O[P#P\/``\?'Q`/+R\@#S\_,`]/3T`/7U]0#V]O8`
M]_?W`/CX^`#Y^?D`^OKZ`/O[^P#\_/P`_?W]`/[^_@#___\`-#0T/#P\/#P\
M/#P\/#P\/#P\/#P\/#P\+`P$!`0$!`1<M-34U-34U-34U-3<U-34U-34U-34
MU-2T-%$$!`0$!&3,[/3T]/ST_/3T]/ST_/3\]/S\_/3T[,0T45$$!`0$9,3D
M[/3T]/3T]/3T]/3T]/3T]/3T].SLO#1145$$!`1DQ.3L[.SD[.SLY.3DY.SL
MY.SD[.SL[.2\-%%145$$!&2\Y.SLK(RLU,24E)R4C(R4E)2<G)SLW+PT45%1
M45$$9+S<Y.SDQ%&4K&3DI$PT+%S$S%&TU.3<O#1145%145%DO-SDY.SDY%&$
M=.2,;*2<;(R\=*S4Y-R\-`0$!`0$!&2\W.3D[.3DO%&,U-2,K,QTS-RD4<3D
MW+PT!`0$!`0$9+S<Y.3DY.3<C'R<M'R$G&S,Y+QTQ.3<M#0$!`0$!`1<O-S<
MY.3DY-2<I%R4C,P\E&3,O(Q1W-2T-`0$!`0$!&2TU-S<W.3<C(RL++RTS%K$
M9)QLE*3<U+0T!`0$!`0$7+34W-SDW-QTE-1,I/2,/-1TE'2<3-S,M#0$!`0$
M!`1DM-3<W-SDW'11]'2$[,QDY'QLI+1LI-2T-`0$!`0$!&2TS-S<S'R,A+3\
MS,3\]+3\O&3,K(11O*PT!`0$!`0$7+3,U,R,I-S<[/S\_/S\]/SLM.RL?)11
MK#0$!`0$!`1<K,S,;)ST_/S\_/S\_/S\_/S\_,24C%&L-`0$!`0$!%RLQ+Q\
MY/S\_/S\_/S\_/S\_/S\[,RL4:PT!`0$!`0$7*RT3,3\_/SL]/S\_/S\_/S\
M_/STO%'$K#0$!`0$!`1<K+1,U/S\]+3<_/S\_/S\_/S\_,Q1S,2D-`0$!`0$
M!%RLQ*11_/S\M)ST_/S\_/S\_/STE%',Q*0L!`0$!`0$7*2D483L_/S,9+3L
M_/S\_/S\_-1LK,R\I#0$!`0$!`1<I&1TO/3\_,11A)SD_/S\_/SDC%',S,2D
M-`0$!`0$!%RD;(SD]/S\G%',493L_/S\_+QTS,S$O)PL!`0$!`0$7*2L9%QD
MI*11K,S$=)3D]/SD4;S,S,2\G#0$!`0$!`1<I+2\O(Q14<3$S,RL47Q\E&Q\
MO,S$Q+R<+`0$!`0$!%R<O,3$Q,3$Q,3$Q,3$45%14;S$Q,3$M)PT!`0$!`0$
M5)RTQ,3$Q,3$Q,3$Q,3$Q,3$Q,3$Q+RTG"P$!`0$!`14G+S$Q+R\O+R\O+R\
MO+R\O+R\O+R\O+2<+`0$!`0$!%R<M,2\M+2TM+2TM+2TM+2TM+2TM+2TK)PL
M!`0$!`0$5(24G)R4E)24E)24E)24E)24E)24E)24A"0$!`0$!`1$5%Q<7%Q<
M7%Q<7%Q<7%Q<7%Q<7%Q<7%Q4-`0$!`0$!````#\````?````#P````<````#
M`````0`````````_````/P```#\````_````/P```#\````_````/P```#\`
M```_````/P```#\````_````/P```#\````_````/P```#\````_````/P``
M`#\````_````/P```#\````_```!``(`$!````$`"`!H!0```0`@(````0`(
M`*@(```"```````!``(`$!````$`"`!H!0```P`@(````0`(`*@(```$````
M7@(T````5@!3`%\`5@!%`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X`
M``$`````````````````````````````````!``$``$`````````````````
M```"`@````!3`'0`<@!I`&X`9P!&`&D`;`!E`$D`;@!F`&\```#>`0`````P
M`#0`,``P`#``-`!B`#`````:``$``0!#`&\`;0!M`&4`;@!T`',`````````
M(@`!``$`0P!O`&T`<`!A`&X`>0!.`&$`;0!E````````````*@`!``$`1@!I
M`&P`90!$`&4`<P!C`'(`:0!P`'0`:0!O`&X````````````B``$``0!&`&D`
M;`!E`%8`90!R`',`:0!O`&X````````````B``$``0!)`&X`=`!E`'(`;@!A
M`&P`3@!A`&T`90`````````F``$``0!,`&4`9P!A`&P`0P!O`'``>0!R`&D`
M9P!H`'0`````````*@`!``$`3`!E`&<`80!L`%0`<@!A`&0`90!M`&$`<@!K
M`',````````````J``$``0!/`'(`:0!G`&D`;@!A`&P`1@!I`&P`90!N`&$`
M;0!E`````````"(``0`!`%``<@!I`'8`80!T`&4`0@!U`&D`;`!D````````
M`"(``0`!`%``<@!O`&0`=0!C`'0`3@!A`&T`90```````````"8``0`!`%``
M<@!O`&0`=0!C`'0`5@!E`'(`<P!I`&\`;@`````````B``$``0!3`'``90!C
M`&D`80!L`$(`=0!I`&P`9```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
2````````````````````````
